@@ -2,6 +2,12 @@ from typing import Any, Optional, List, Dict, Tuple, Union
 from typing_extensions import TypedDict, Literal
 
 
+S3Config = TypedDict('S3Config', {
+    "accern_aws_key": str,
+    "accern_aws_access_key": str,
+    "model_download_bucket": str,
+    "model_download_path": List[str],
+})
 DagDef = TypedDict('DagDef', {
     "company": str,
     "default_input_key": Optional[str],
